@@ -1,4 +1,4 @@
-from . import utils, masking, dvd, cursed # noqa F401
+from . import utils, masking, dvd, cursed  # noqa: F401
 
 # Alias for script compatibility
 batchindex = utils.batch_index
