@@ -7,8 +7,8 @@ core = vs.core
 
 def scradit_mask(luma: vs.VideoNode, b: float = 1/3, c: float = 1/3,
                  height: int = 720, absthresh: float = 0.060, iters: int = 4,
-                 descaler: Callable[[vs.VideoNode, Any], vs.VideoNode] = core.descale.Debicubic, # noqa 501
-                 upscaler: Callable[[vs.VideoNode, Any], vs.VideoNode] = core.resize.Bicubic, # noqa 501
+                 descaler: Callable[[vs.VideoNode, Any], vs.VideoNode] = core.descale.Debicubic,  # type: ignore  # noqa: E501
+                 upscaler: Callable[[vs.VideoNode, Any], vs.VideoNode] = core.resize.Bicubic,  # noqa: E501
                  dekwargs: Dict = {}, upkwargs: Dict = {}) -> vs.VideoNode:
     """ Credit masking function borrowed from Scrad.
 
@@ -31,12 +31,12 @@ def scradit_mask(luma: vs.VideoNode, b: float = 1/3, c: float = 1/3,
     luma = vsutil.get_y(luma)
     luma = vsutil.depth(luma, 32)
     descaled = descaler(luma, vsutil.get_w(height, luma.width/luma.height),
-                        height, b=b, c=c, **dekwargs)
-    rescaled = upscaler(descaled, luma.width, luma.height, **upkwargs)
-    mask = core.std.Expr([luma, rescaled], f'x y - abs {absthresh} < 0 1 ?')
+                        height, b=b, c=c, **dekwargs)  # type: ignore
+    rescaled = upscaler(descaled, luma.width, luma.height, **upkwargs)  # type: ignore  # noqa: E501
+    mask = core.std.Expr([luma, rescaled], f"x y - abs {absthresh} < 0 1 ?")
     mask = vsutil.iterate(mask, core.std.Maximum, iters)
     mask = vsutil.iterate(mask, core.std.Inflate, iters)
-    return mask
+    return mask  # noqa: R504
 
 
 def detail_mask(source: vs.VideoNode, rescaled: vs.VideoNode,
@@ -53,17 +53,18 @@ def detail_mask(source: vs.VideoNode, rescaled: vs.VideoNode,
     """
     sy = vsutil.get_y(source)
     ry = vsutil.get_y(rescaled)
-    sy = core.resize.Point(sy, format=ry.format.id) if not sy.format.id == ry.format.id else sy # noqa 501
-    mask = core.std.Expr([sy, ry], 'x y - abs').std.Binarize(thresh)
+    sy = core.resize.Point(sy, format=ry.format.id) if not sy.format.id == ry.format.id else sy  # type: ignore  # noqa: E501
+    mask = core.std.Expr([sy, ry], "x y - abs").std.Binarize(thresh)
     mask = vsutil.iterate(mask, core.std.Maximum, 4)
     mask = vsutil.iterate(mask, core.std.Inflate, 4)
-    return mask
+    return mask  # noqa: R504
 
 
 def dehalo_mask(clip: vs.VideoNode,
-                maskgen: Callable[[vs.VideoNode, Any], vs.VideoNode] = core.std.Prewitt, # noqa 501
+                maskgen: Callable[[vs.VideoNode, Any], vs.VideoNode] = core.std.Prewitt,  # noqa: E501
                 iter_out: int = 2, iter_in: int = -1, inner: bool = False,
-                outer: bool = False, **mask_args) -> vs.VideoNode:
+                outer: bool = False, **mask_args: Dict[str, Any]
+                ) -> vs.VideoNode:
     """ Lazy wrapper for making a dehalo mask.
 
     Expects a YUV clip. No idea what happens when anything else is passed,
@@ -80,7 +81,7 @@ def dehalo_mask(clip: vs.VideoNode,
     :param outer:       Returns the outer mask for checking.
     :param mask_args:   Expanded as ``**kwargs`` for ``mask_gen``
     """
-    mask = maskgen(clip, **mask_args) if mask_args else maskgen(clip, 0)
+    mask = maskgen(clip, **mask_args) if mask_args else maskgen(clip, 0)  # type: ignore  # noqa: E501
     luma = core.std.ShufflePlanes(mask, 0, colorfamily=vs.GRAY)
     mout = vsutil.iterate(luma, core.std.Maximum, iter_out)
     if outer:
@@ -92,7 +93,7 @@ def dehalo_mask(clip: vs.VideoNode,
     return core.std.Expr([mout, minn], "x y -")
 
 
-def fineline_mask(clip: vs.VideoNode, thresh: int = 95):
+def fineline_mask(clip: vs.VideoNode, thresh: int = 95) -> vs.VideoNode:
     """ Generates a very fine mask for lineart protection. Not perfect yet
     The generated mask is GRAY8, keep this in mind for conversions.
 
@@ -106,6 +107,5 @@ def fineline_mask(clip: vs.VideoNode, thresh: int = 95):
     maska = core.std.Expr([yp, yt], ["x y < y x ?"])
     bin_mask = core.std.Binarize(maska, threshold=thresh)
     redo = int(floor(thresh/2.5)*2)
-    mask_out = core.std.Expr([bin_mask, maska],
-                             [f"x y < y x ? {redo} < 0 255 ?"])
-    return mask_out
+    return core.std.Expr([bin_mask, maska],
+                         [f"x y < y x ? {redo} < 0 255 ?"])
